@@ -89,7 +89,12 @@ gconf_bookmarks_dialog_populate_model (GConfBookmarksDialog *dialog)
 		gtk_list_store_set (dialog->list_store, &iter,
 				    0, p->data,
 				    -1);
+		g_free (p->data);
 	}
+
+	if (value_list)
+		g_slist_free (value_list);
+
 	dialog->changing_model = FALSE;
 
 	g_object_unref (client);
@@ -182,7 +187,6 @@ gconf_bookmarks_dialog_init (GConfBookmarksDialog *dialog)
 	GtkWidget *scrolled_window, *hbox, *vbox;
 	GtkCellRenderer *cell;
 	GtkTreeViewColumn *column;
-	GdkPixbuf *pixbuf;
 	GConfClient *client;
        
 	hbox = gtk_hbox_new (FALSE, 6);
@@ -215,11 +219,9 @@ gconf_bookmarks_dialog_init (GConfBookmarksDialog *dialog)
 	column = gtk_tree_view_column_new ();
 
 	cell = gtk_cell_renderer_pixbuf_new ();
-	pixbuf = gtk_widget_render_icon (dialog->tree_view, STOCK_BOOKMARK, GTK_ICON_SIZE_MENU, NULL);
 	g_object_set (G_OBJECT (cell),
-		      "pixbuf", pixbuf,
+		      "stock-id", STOCK_BOOKMARK,
 		      NULL);
-	g_object_unref (pixbuf);
 	gtk_tree_view_column_pack_start (column, cell, FALSE);
 	
 	cell = gtk_cell_renderer_text_new ();
