@@ -21,7 +21,7 @@
 #define __GCONF_BOOKMARKS_H__
 
 #include "gconf-editor-window.h"
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 void gconf_bookmarks_hook_up_menu (GConfEditorWindow *window,
 				   GtkWidget         *menu,
