@@ -388,6 +388,7 @@ gconf_list_model_finalize (GObject *object)
 
         if (list_model->client) {
                 g_object_unref (list_model->client);
+		list_model->client = NULL;
         }
 
 	if (list_model->values) {
@@ -421,8 +422,11 @@ gconf_list_model_init (GConfListModel *model)
 void
 gconf_list_model_set_client (GConfListModel *model, GConfClient *client)
 {
-	g_object_unref (model->client);
-	model->client = client;
+	if (model->client != NULL) {
+		g_object_unref (model->client);
+	}
+
+	model->client = g_object_ref (client);
 }
 
 GtkTreeModel *
